X-Git-Url: https://git.p6c8.net/jirafeau_project.git/blobdiff_plain/f58031f40640cc7c243a32d2c3515210ef4ed282..0f19030a1068536908216dc87e7a38ee9a235372:/lib/config.original.php?ds=sidebyside

diff --git a/lib/config.original.php b/lib/config.original.php
index fa0f034..c0a1ed3 100644
--- a/lib/config.original.php
+++ b/lib/config.original.php
@@ -34,17 +34,15 @@ $cfg['var_root'] = '';
  */
 $cfg['lang'] = 'auto';
 /* Select your style :) See media folder */
-$cfg['style'] = 'modern';
-/* Propose a preview link if file type is previewable is set to true. */
+$cfg['style'] = 'courgette';
+/* Propose a preview link if file type is previewable. */
 $cfg['preview'] = true;
-/* Download page: propose a link to a download page is set to true. */
-$cfg['download_page'] = true;
 /* Encryption feature. disable it by default.
  * By enabling it, file-level deduplication won't work.
  */
 $cfg['enable_crypt'] = false;
-/* Split lenght of link refenrece. */
-$cfg['link_name_lenght'] = 8;
+/* Split length of link refenrece. */
+$cfg['link_name_length'] = 8;
 /* Upload password(s). Empty array disable password authentification.
  * $cfg['upload_password'] = array();               // No password
  * $cfg['upload_password'] = array('psw1');         // One password
@@ -80,6 +78,10 @@ $cfg['availabilities'] = array ('minute' => true,
                                 'month' => true,
                                 'year' => false,
                                 'none' => false);
+/* Set maximal upload size expressed in MB.
+ * 0 mean unlimited upload size.
+ */
+$cfg['maximal_upload_size'] = 0;
 /* Installation is done ? */
 $cfg['installation_done'] = false;